.. _ucredentials:

UCredentialManager Class
########################

.. autoclass:: urgap.UCredentialManager
   :members:

   .. automethod:: __init__


UCredentials IO Classes
#######################

.. autoclass:: urgap.ucredentials.io._base.IOBaseCreds
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ucredentials.io.akv.IOAzureCreds
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ucredentials.io.gcp.IOGCPCreds
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ucredentials.io.env.IOEnvCreds
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ucredentials.io.echo.IOEchoCreds
   :members:

   .. automethod:: __init__
